import React from 'react';
import 'katex/dist/katex.min.css';
import 'highlight.js/styles/github-dark.css';
export interface MarkdownProps {
    /**
     * The ID of this component, used to identify dash components
     * in callbacks. The ID needs to be unique across all of the
     * components in an app.
     */
    id?: string;
    /**
     * Class name of the container element
     */
    className?: string;
    /**
     * Remove matching leading whitespace from all lines.
     * Lines that are empty, or contain *only* whitespace, are ignored.
     * Both spaces and tab characters are removed, but only if they match;
     * we will not convert tabs to spaces or vice versa.
     */
    dedent?: boolean;
    /**
     * Object that holds the loading state object coming from dash-renderer
     */
    loading_state?: any;
    /**
     * User-defined inline styles for the rendered Markdown
     */
    style?: any;
}
/**
 * A custom re-worked version of dcc.Markdown.
 * Uses v6 of react-markdown and applies four plugins
 * to the markdown component by default:
 * - remark-slug
 * - remark-highlight.js
 * - remark-math
 * - rehype-katex
 */
export declare const Markdown: React.FC<MarkdownProps>;
