import React from 'react';
import { SearchContextValue, SearchState } from '../types';
/**
 * Two contexts are invoked inside the SearchUI component
 * SearchUIContext exposes the search state to all of its consumers
 * SearchUIContextActions exposes the methods (i.e. actions) for modifying the search state
 */
export declare const SearchUIContext: React.Context<SearchContextValue | undefined>;
export declare const SearchUIContextActions: React.Context<any>;
/**
 * Component that wraps all of its children in providers for SearchUIContext and SearchUIContextActions
 * Accepts the same props as SearchUI and uses them to build the context state
 */
export declare const SearchUIContextProvider: React.FC<SearchState>;
/**
 * Custom hook for consuming the SearchUIContext
 * Must only be used by child components of SearchUIContextProvider
 * The context returns one property called "state"
 */
export declare const useSearchUIContext: () => SearchContextValue;
/**
 * Custom hook for consuming the SearchUIContextActions
 * Must only be used by child components of SearchUIContextProvider
 * The context returns one property called "actions"
 */
export declare const useSearchUIContextActions: () => any;
