import React from 'react';
import '../RangeSlider/RangeSlider.css';
export interface DualRangeSliderProps {
    /**
     * The ID used to identify this component in Dash callbacks
     */
    id?: string;
    /**
     * Dash-assigned callback that should be called whenever any of the
     * properties change
     */
    setProps?: (value: any) => any;
    /**
     * Class name(s) to append to the component's default class.
     */
    className?: string;
    /**
     * Array with the minimum and maximum possible values.
     * Note that the domain bounds will be made "nice" so that
     * the slider ticks can be placed on easy-to-read numbers.
     */
    domain: number[];
    /**
     * Array with the min and max values that the slider
     * should be set to.
     */
    value?: number[];
    valueMin?: number;
    valueMax?: number;
    /**
     * Number by which the slider handles should move with each step.
     * Defaults to 1.
     */
    step: number;
    /**
     * Use a logarithmic scale for the slider.
     * Domain values will be interpreted as exponents and will be transformed to be `10^x`.
     * So a domain of `[-1, 2]` will yields a range of `[0.01, 100]`.
     * Note that when using a log scale, the `value` prop will always be the pre-transformed value.
     */
    isLogScale?: boolean;
    /**
     * Number of milliseconds that should pass between typing into the slider
     * number input and the slider handles updating.
     */
    debounce?: number;
    /**
     * Number of ticks to show on the slider scale.
     * Note that D3 will automatically convert this number to a multiple of 1, 2, 5, or 10.
     * Set to 2 to only include ticks at the min and max bounds of the scale.
     */
    ticks?: number | null;
    /**
     * Set to true to display a "+" with the upper bound tick (e.g. "100+").
     * Use this to indicate that the upper bound is inclusive (e.g. 100 or more).
     */
    inclusiveTickBounds?: boolean;
    /**
     * Function to call when slider values change.
     */
    onChange?: (min: number, max: number) => void;
    /**
     * Function to call when the slider props change.
     * This can be used to lift the new "nice" domain upwards.
     */
    onPropsChange?: (props: any) => void;
}
/**
 * Slider input with controls for both the minimum and maximum bounds.
 */
export declare const DualRangeSlider: React.FC<DualRangeSliderProps>;
