/// <reference types="react" />
export declare enum DownloadType {
    JSON = "json",
    CSV = "csv"
}
declare type DownloadTypeObject = Partial<Record<DownloadType, any>>;
export declare const convertArrayOfObjectsToCSV: (array: any[]) => any;
export declare const downloadCSV: (array: any[], filename?: string | undefined) => boolean;
export declare const createLink: (dataStr: string, filename: string) => void;
export declare const downloadJSON: (data: any, filename?: string | undefined) => boolean;
export declare const downloadBlob: (blob: Blob, filename?: string | undefined, rel?: string | undefined) => void;
/**
 * Commenting this feature out for now so that we can removed the xlsx dependency.
 * We can restore if we decide to implement client-side Excel exports.
 */
export declare const downloadAs: DownloadTypeObject;
/**
 * Determine if a string is delimited by commas, hyphens, or spaces
 * Return the delimiter as a regular expression object
 * If multiple delimiters are present, the delimiter with the lowest index is used
 */
export declare const getDelimiter: (input: string) => RegExp | undefined;
export declare function elementsArrayToElementState(elements: string[]): {};
/**
 * Split formula string into two kinds of arrays:
 * 1. One with numbers e.g. [Eu2, Si, N3]
 * 2. One without numbers e.g. [Eu, Si, N]
 *
 * Wildcards are included as elements e.g. [Eu, Si, N, *, *]
 */
export declare function formulaStringToArrays(str: string): {
    formulaSplitWithNumbers: RegExpMatchArray | null;
    formulaSplitElementsOnly: string[];
};
export declare function getTruthyKeys(obj: any): string[];
export declare function arrayToDelimitedString(arr: any[], delimiter?: string | RegExp): string;
export declare const countDecimals: (value: number) => number;
export declare const initArray: (length: number, value: any) => any[];
export declare const spaceGroupNumberOptions: () => {
    value: number;
    label: number;
}[];
export declare const spaceGroupSymbolOptions: () => {
    value: string;
    label: string;
}[];
export declare const crystalSystemOptions: () => any;
export declare const pointGroupOptions: () => {
    value: string;
    label: string;
}[];
export declare const pluralize: (noun: any) => string;
export declare const capitalize: (str: string) => string;
/**
 * Perform a naive validation of a string as a formula
 * Returns the string if it has more than one capital letter, a number, or wildcard character ("*")
 * Returns null if the string is not a "parsable" formula
 */
export declare const parseFormula: (str: string) => string | null;
export declare const formatPointGroup: (pointGroup: string) => JSX.Element;
export declare const formatFormula: (formula: string) => JSX.Element;
/**
 * Get number of pages based on total results and page limit
 * If no results, return 1 to prevent errors with query
 */
export declare const getPageCount: (totalResults: number, resultsPerPage: number) => number;
export declare const sortDynamic: (field: any, asc?: any) => (a: any, b: any) => number;
export declare const sortCrossref: (field: any, asc?: any) => (a: any, b: any) => number;
export declare function mapArrayToBooleanObject(array: any, value?: boolean): any;
export declare const validateValueInRange: (value: number, min: number, max: number) => number;
export declare const convertToNumber: (value: number | string) => number;
export declare const initSliderScale: (domain: number[], isLogScale?: boolean | undefined) => any;
export declare const initSliderTicks: (ticks: number | null, domain: number[], scale?: any) => any;
/**
 * Convert value to 10^value and handle the amount of decimals to fix the number to.
 * For exponents 0 or more, only show whole numbers.
 * For exponents less than 0, the exponent value will determine the number of decimals
 * (e.g. -1 -> 1 decimal place, -1.3 -> 2 decimal places).
 */
export declare const pow10Fixed: (value: number) => string;
export {};
