export declare enum Renderer {
    SVG = "svg",
    WEBGL = "webgl"
}
export declare enum ExportType {
    png = "png",
    dae = "dae",
    gltf = "gltf",
    usdz = "usdz"
}
export declare enum Material {
    standard = "MeshStandardMaterial"
}
export declare enum Light {
    DirectionalLight = "DirectionalLight",
    AmbientLight = "AmbientLight",
    HemisphereLight = "HemisphereLight"
}
export declare const DEFAULT_LIGHT_COLOR = "#444444";
export declare enum Control {
    TRACKBALL = "trackball",
    ORBIT = "orbit"
}
export declare enum AnimationStyle {
    PLAY = "play",
    SLIDER = "slider",
    NONE = "none"
}
export declare enum CameraAxis {
    X = "x",
    Y = "y",
    Z = "z"
}
export declare enum CameraPosition {
    BACK = "back",
    FRONT = " front"
}
export declare const TUBE_SEGMENTS = 150;
export declare const RADIUS_SEGMENTS = 20;
export declare const defaults: {
    antialias: boolean;
    cameraAxis: string;
    cameraPosition: string;
    animation: AnimationStyle;
    transparentBackground: boolean;
    renderer: Renderer;
    renderDivBackground: boolean;
    background: string;
    sphereSegments: number;
    cylinderSegments: number;
    staticScene: boolean;
    sphereScale: number;
    cylinderScale: number;
    extractAxis: boolean;
    defaultSurfaceOpacity: number;
    lights: ({
        type: Light;
        args: (string | number)[];
        position?: undefined;
    } | {
        type: Light;
        args: (string | number)[];
        position: number[];
    })[];
    material: {
        type: Material;
        parameters: {
            roughness: number;
            metalness: number;
        };
    };
    controls: Control;
    enableZoom: boolean;
    secondaryObjectView: boolean;
    defaultZoom: number;
    zoomToFit2D: boolean;
};
export declare enum JSON3DObject {
    ELLIPSOIDS = "ellipsoids",
    CYLINDERS = "cylinders",
    SPHERES = "spheres",
    ARROWS = "arrows",
    CUBES = "cubes",
    LINES = "lines",
    SURFACES = "surface",
    CONVEX = "convex",
    LABEL = "labels",
    BEZIER = "bezier"
}
export declare const DEBUG_STYLE: {
    width: string;
    height: string;
    top: number;
    left: string;
    position: "absolute";
};
export declare const MOUNT_NODE_STYLE: {
    position: "absolute";
};
export declare const MOUNT_NODE_CLASS = "three-container";
export declare const MOUNT_DEBUG_NODE_CLASS = "three-debug-container";
export declare const DEFAULT_SCENE_SIZE = 500;
export declare enum FieldType {
    VEC3 = "vec3",
    VEC3_PAIRS = "vec3Pair",
    COLOR = "color",
    NUMBER = "number",
    LIST = "list"
}
export interface Field {
    name: string;
    type: FieldType;
    id: string;
    listSize?: number;
    listModel?: FieldType;
}
export declare const fieldIndex: {
    [id: string]: Field;
};
export declare const OBJECT_TO_FIELDS: {
    [K in JSON3DObject]: Field[] | null;
};
export declare type ThreePosition = [number, number, number];
