import React from 'react';
import './Drawer.css';
export interface EnlargeableProps {
    /**
     * A unique ID to use to open and close the drawer in its `DrawerContextProvider`.
     * This id should be passed to the `forDrawerId` prop in a `DrawerTrigger`
     * that sits inside the same `DrawerContextProvider`.
     * Also used to identify this component in Dash callbacks.
     */
    id: string;
    /**
     * Dash-assigned callback that should be called to report property changes
     * to Dash, to make them available for callbacks.
     */
    setProps?: (value: any) => any;
    /**
     * Additional class to apply to drawer
     */
    className?: string;
}
/**
 * Render a right-side drawer that can be opened and closed.
 * A `Drawer` must be used inside of a `DrawerContextProvider` and must have a
 * corresponding `DrawerTrigger` within the same context.
 * The `id` of a drawer should be passed to the `forDrawerId` prop of a `DrawerTrigger` to open/close the drawer.
 */
export declare const Drawer: React.FC<EnlargeableProps>;
