import React from 'react';
interface ModalState {
    active: boolean;
    setActive: (value: any) => any;
    forceAction: boolean;
    setForceAction: (value: any) => any;
}
export interface ModalContextProviderProps {
    /**
     * Dash-assigned callback that should be called whenever any of the
     * properties change
     */
    setProps?: (value: any) => any;
    /**
     * The current or default state of the modal. If true, the "is-active" class is added to <Modal/>.
     * This value can be watched and changed from outside the component (e.g. via dash callback).
     */
    active?: boolean;
    /**
     * Prevent modal from being closed without completion of a specific action.
     * If set, there must be a button within the modal that updates the "active"
     * state using the ModalContext or a dash callback on the active prop.
     */
    forceAction?: boolean;
}
/**
 * Wrap a `ModalTrigger` component and a `Modal` component inside a `ModalContextProvider` to render an element (trigger) that
 * will open up a modal. Apply props to the `ModalContextProvider`.
 */
export declare const ModalContextProvider: React.FC<ModalContextProviderProps>;
/**
 * Custom hook for consuming the ModalContext
 * Must only be used by child components of ModalContextProvider
 */
export declare const useModalContext: () => ModalState;
export {};
