import { ActiveFilter, FilterGroup } from './types';
import { MaterialsInputType } from '../../data-entry/MaterialsInput';
import { MaterialsInputTypesMap } from '../../data-entry/MaterialsInput/utils';
import { DecodedValueMap, QueryParamConfigMap } from 'use-query-params';
/**
 * Check whether a filter value is considered empty or not (i.e. active or inactive)
 */
export declare const isNotEmpty: (value: any) => boolean;
/**
 * Initialize filter groups to be usable within the search state.
 * This allows options to be programatically added for symmetry filters.
 * @param filterGroups array filter definitions nested by group
 * @returns new array of filter groups ready to use in the state
 */
export declare const initFilterGroups: (filterGroups: FilterGroup[]) => FilterGroup[];
/**
 * Update the search state's active filters.
 * The activeFilters list is recomputed whenever a filter is modified in the UI.
 */
export declare const getActiveFilters: (filterGroups: FilterGroup[], query: DecodedValueMap<QueryParamConfigMap>) => ActiveFilter[];
/**
 * Create the query param config object based on the filter definitions.
 * This determines the keys in the query param object and assigns param types
 * to each key to determine how the param is encoded/decoded in the URL.
 * @param filterGroups filter definitions by nested group
 * @param sortKey key to use for the sort param
 * @param limitKey key to use for the result limit param
 * @param skipKey key to use for the skip amount (which index should the range of results start from)
 * @returns config that maps query params to param types
 */
export declare const initQueryParams: (filterGroups: FilterGroup[], sortKey: string, limitKey: string, skipKey: string) => QueryParamConfigMap;
/**
 * Apply transformations to the query param values before sending them to the API.
 * @param query object of query params and their values.
 * @param filterGroups filter definitions nested by group.
 * @param defaultQuery
 * @returns object of query params with API-ready values.
 */
export declare const preprocessQueryParams: (query: DecodedValueMap<QueryParamConfigMap>, filterGroups: FilterGroup[], defaultQuery: any, sortParamKey: string) => {};
export declare const convertMaterialsInputTypesMapToArray: (map: MaterialsInputTypesMap) => MaterialsInputType[];
export declare const mapInputTypeToField: (inputType: MaterialsInputType, allowedInputTypesMap: MaterialsInputTypesMap) => any;
