import React, { ReactNode } from 'react';
export interface TabsProps {
    /**
     * The ID used to identify this component in Dash callbacks
     */
    id?: string;
    /**
     * Dash-assigned callback that should be called whenever any of the
     * properties change
     */
    setProps?: (value: any) => any;
    /**
     * Class name applied to top level wrapper for tabs and tab content.
     * The "mpc-tabs" class is added automatically
     */
    className?: string;
    /**
     * Content for each tab. Each top-level element will be the content for a tab.
     * The order of the elements inside of children should correspond to the order of the `labels` prop.
     */
    children: ReactNode;
    /**
     * List of strings to use as labels for the tabs.
     * The number of labels must equal the number of children (i.e. tab content items).
     */
    labels: string[];
    /**
     * The current or default tabIndex to be active.
     * This value can be watched and changed from outside the component (e.g. via dash callback).
     */
    tabIndex?: number;
    /**
     * Allow an object of arbitrary props to also
     * be added to the react-tabs component.
     *
     * This is workaround to let the Dash component
     * version of this component accept extra props
     * supported by react-tabs without the need to explicitly
     * define those props in the component's propTypes.
     */
    arbitraryProps?: object;
}
/**
 * Render content as labeled tabs.
 * This component will only render a tab's content once it has been activated.
 * After it's been activated, the tab's content will stay rendered and will be
 * shown/hidden using css only.
 * The react-tabs library is used under the hood but usage has been modified to make this component dash-friendly.
 * See https://github.com/reactjs/react-tabs
 */
export declare const Tabs: React.FC<TabsProps>;
