/// <reference types="react" />
import './periodic-table.module.less';
import { MatElement } from '../periodic-table-data/table-v2';
export declare const DEFAULT_HEATMAP_COLOR = "#EDEEED";
export declare const COLORSCHEME: {
    Viridis: any;
    Turbo: any;
    CubeHelix: any;
    Cividis: any;
    Inferno: any;
    Blues: any;
    Oranges: any;
    Greens: any;
    Reds: any;
    Purples: any;
};
export interface TableProps {
    className?: string;
    /** dictionnary of disabled elements */
    disabledElement: {
        [symbol: string]: boolean;
    };
    /** dictionnary of enabled elements  */
    enabledElement: {
        [symbol: string]: boolean;
    };
    /** dictonnary of hidden elements */
    hiddenElement: {
        [symbol: string]: boolean;
    };
    /** Callback who gets called once the user clicked an element; the clicked element is passed **/
    onElementClicked: (mat: MatElement) => void;
    onElementMouseOver: (mat: MatElement) => void;
    onElementMouseLeave?: (mat: MatElement) => void;
    /** Force the layout of the table **/
    forceTableLayout?: TableLayout;
    /** Colorize the table by using an heatmap
     *  id: symbol of the element
     *  value: value used for the heatmap
     **/
    heatmap?: {
        [id: string]: number;
    };
    /** Color scheme to use. Look at the COLORSCHEME definition for available color scheme
     *  If you pass an unknown color scheme or no scheme, the component will use a linear scale whose range
     *  is defined by the heatmapMax and heatmapMin value
     **/
    colorScheme?: keyof typeof COLORSCHEME;
    /** Color used for the highest value */
    heatmapMax?: string;
    /** Color used for the lowest value*/
    heatmapMin?: string;
    showSwitcher?: boolean;
    plugin?: JSX.Element;
    children?: any;
    selectorWidget?: any;
    /** toggle disabling all table components */
    disabled?: boolean;
}
export declare enum TableLayout {
    SPACED = "spaced",
    COMPACT = "compact",
    MINI = "small",
    MAP = "map"
}
export declare function Table({ className, disabledElement, enabledElement, hiddenElement, onElementClicked, onElementMouseOver, onElementMouseLeave, forceTableLayout, heatmap, heatmapMax, heatmapMin, colorScheme, showSwitcher, selectorWidget, plugin, disabled }: TableProps): JSX.Element;
