import { Observable } from 'rxjs';
import * as React from 'react';
interface ElementState {
    [symbol: string]: boolean;
}
export interface State {
    disabledElements: ElementState;
    enabledElements: ElementState;
    hiddenElements: ElementState;
    detailedElement: string | null;
    forwardOuterChange: boolean;
    lastAction: {
        type: 'select' | 'deselect';
        element: string;
    };
}
export declare enum TableSelectionStyle {
    ENABLE_DISABLE = "enableDisable",
    SELECT = "select",
    MULTI_INPUTS_SELECT = "mis"
}
export declare function getPeriodicSelectionStore(): {
    observable: Observable<State>;
    actions: {
        init: (initialState?: State) => void;
        selectionStyle: TableSelectionStyle;
        currentElementIndex: number;
        selectedElements: any;
        setForwardChange: (fwdChange: any) => any;
        setEnabledElements: (enabledElements: any) => void;
        setDisabledElements: (disabledElements: any) => void;
        clear: () => void;
        setDetailedElement: (el: string | null) => void;
        setHiddenElements: (hiddenElements: any) => void;
        addEnabledElement: (enabledElement: string) => void;
        toggleDisabledElement: (disabledElement: string) => void;
        addDisabledElement: (disabledElement: string) => void;
        removeEnabledElement: (enabledElement: string) => void;
        removeDisabledElement: (disabledElement: string) => void;
        toggleEnabledElement: (enabledElement: string) => void;
        setMaxSelectionLimit: (maxItem: number) => void;
    };
};
export declare const PeriodicSelectionContext: React.Context<{
    observable: Observable<State>;
    actions: {
        init: (initialState?: State) => void;
        selectionStyle: TableSelectionStyle;
        currentElementIndex: number;
        selectedElements: any;
        setForwardChange: (fwdChange: any) => any;
        setEnabledElements: (enabledElements: any) => void;
        setDisabledElements: (disabledElements: any) => void;
        clear: () => void;
        setDetailedElement: (el: string | null) => void;
        setHiddenElements: (hiddenElements: any) => void;
        addEnabledElement: (enabledElement: string) => void;
        toggleDisabledElement: (disabledElement: string) => void;
        addDisabledElement: (disabledElement: string) => void;
        removeEnabledElement: (enabledElement: string) => void;
        removeDisabledElement: (disabledElement: string) => void;
        toggleEnabledElement: (enabledElement: string) => void;
        setMaxSelectionLimit: (maxItem: number) => void;
    };
}>;
/**
 *
 * Call this function inside a component. It will make the components aware of which elements are selected/disabled
 * Be careful, as this will trigger a rendering every time a component is selected/unselected
 *
 **/
export declare function useElements(maxElementSelection?: number, onStateChange?: any): {
    disabledElements: {};
    enabledElements: {};
    hiddenElements: {};
    lastAction: {
        type: "select" | "deselect";
        element: string;
    } | undefined;
    actions: {
        init: (initialState?: State) => void;
        selectionStyle: TableSelectionStyle;
        currentElementIndex: number;
        selectedElements: any;
        setForwardChange: (fwdChange: any) => any;
        setEnabledElements: (enabledElements: any) => void;
        setDisabledElements: (disabledElements: any) => void;
        clear: () => void;
        setDetailedElement: (el: string | null) => void;
        setHiddenElements: (hiddenElements: any) => void;
        addEnabledElement: (enabledElement: string) => void;
        toggleDisabledElement: (disabledElement: string) => void;
        addDisabledElement: (disabledElement: string) => void;
        removeEnabledElement: (enabledElement: string) => void;
        removeDisabledElement: (disabledElement: string) => void;
        toggleEnabledElement: (enabledElement: string) => void;
        setMaxSelectionLimit: (maxItem: number) => void;
    };
};
export declare function useDetailedElement(): string;
export {};
