import React from 'react';
import './PublicationButton.css';
export interface PublicationButtonProps {
    /**
     * The ID used to identify this component in Dash callbacks
     */
    id?: string;
    /**
     * Class name(s) to append to the component's default class (mpc-publication-button)
     * @default 'tag'
     */
    className?: string;
    /**
     * The DOI (Digital Object Identifier) of the publication
     * Will be used to generate a doi.org link and to fetch the journal name and year.
     */
    doi?: string;
    /**
     * Directly supply the URL to the publication.
     * If a doi.org url is supplied, this component will automatically
     * parse the url for the doi and use that to fetch the journal name and year.
     */
    url?: string;
    /**
     * Value to add to the anchor tag's target attribute
     * @default '_blank'
     */
    target?: string;
    /**
     * Only display the publication icon and hide the link label.
     * If true, `showTooltip` will default to true.
     */
    compact?: boolean;
    /**
     * Show a tooltip on hover with the bibliographic citation for the publication.
     */
    showTooltip?: boolean;
}
/**
 * Standardized button for linking to a publication.
 *
 * This component can be used in four ways:
 * 1. Supply just a `doi` and let the component build the url and fetch the journal name and year from crossref.
 * 2. Supply just a `url` to doi.org and fetch the journal name and year from crossref.
 * 3. Supply a `doi` and a link label in the component's `children`. In this case, there will be no fetch to crossref.
 * 4. Supply a `url` to any location and a link label in the component's `children`. In this case, there will be no fetch to crossref.
 */
export declare const PublicationButton: React.FC<PublicationButtonProps>;
